summaryrefslogtreecommitdiffabout
path: root/kmicromail/koprefsdialog.cpp
authorzautrix <zautrix>2004-09-22 00:34:51 (UTC)
committer zautrix <zautrix>2004-09-22 00:34:51 (UTC)
commit01572248367c63119514d15d7401a5b2b83349a0 (patch) (side-by-side diff)
tree892544498d4b989a9c319b21b243b818652e9718 /kmicromail/koprefsdialog.cpp
parentcc0e64e64da1b2d25dd95ab6d2c2f55bd8822e8f (diff)
downloadkdepimpi-01572248367c63119514d15d7401a5b2b83349a0.zip
kdepimpi-01572248367c63119514d15d7401a5b2b83349a0.tar.gz
kdepimpi-01572248367c63119514d15d7401a5b2b83349a0.tar.bz2
make it compile
Diffstat (limited to 'kmicromail/koprefsdialog.cpp') (more/less context) (ignore whitespace changes)
-rw-r--r--kmicromail/koprefsdialog.cpp74
1 files changed, 37 insertions, 37 deletions
diff --git a/kmicromail/koprefsdialog.cpp b/kmicromail/koprefsdialog.cpp
index 87a6715..7d7bd2a 100644
--- a/kmicromail/koprefsdialog.cpp
+++ b/kmicromail/koprefsdialog.cpp
@@ -95,7 +95,7 @@ KOPrefsDialog::~KOPrefsDialog()
{
}
-void KOPrefsDialog::setupMainTab()
+void KOPrefsDialog::setupMainTab()
{
QFrame *topFrame = addPage(i18n("General"),0,0);
@@ -115,7 +115,7 @@ void KOPrefsDialog::setupMainTab()
topLayout->addWidget(mEmailEdit,1,1);
QLabel *lab = new QLabel( i18n("HINT: Separate multiple\neMail addresses by \";\""), topFrame);
topLayout->addMultiCellWidget(lab,2,2,0,1);
- KPrefsWidBool* ttt = addWidBool(i18n("Ignore above settings and\nuse KA/Pi \"Who am I\" instead!"),
+ KPrefsDialogWidBool* ttt = addWidBool(i18n("Ignore above settings and\nuse KA/Pi \"Who am I\" instead!"),
&(KOPrefs::instance()->mUseKapi),topFrame);
topLayout->addMultiCellWidget(ttt->checkBox(),3,3,0,1);
}
@@ -128,7 +128,7 @@ void KOPrefsDialog::setupMailTab()
topLayout->setSpacing(spacingHint());
topLayout->setMargin(marginHint());
- KPrefsWidBool* ttt = addWidBool(i18n("View mail as html"),
+ KPrefsDialogWidBool* ttt = addWidBool(i18n("View mail as html"),
&(KOPrefs::instance()->mViewAsHtml),topFrame);
topLayout->addMultiCellWidget(ttt->checkBox(),0,0,0,1);
@@ -148,9 +148,9 @@ void KOPrefsDialog::setupFontsTab()
QGridLayout *topLayout = new QGridLayout(topFrame,7,3);
topLayout->setSpacing(1);
topLayout->setMargin(3);
- KPrefsWidFont * tVFont;
+ KPrefsDialogWidFont * tVFont;
int i = 0;
- KPrefsWidFont *timeLabelsFont =
+ KPrefsDialogWidFont *timeLabelsFont =
addWidFont(i18n("OK"),i18n("Application(nr)"),
&(KOPrefs::instance()->mAppFont),topFrame);
topLayout->addWidget(timeLabelsFont->label(),i,0);
@@ -167,7 +167,7 @@ void KOPrefsDialog::setupFontsTab()
topLayout->addWidget(timeLabelsFont->button(),i,2);
++i;
- KPrefsWidFont *timeBarFont =
+ KPrefsDialogWidFont *timeBarFont =
addWidFont(i18n("Hello"),i18n("Read mail:"),
&(KOPrefs::instance()->mReadFont),topFrame);
topLayout->addWidget(timeBarFont->label(),i,0);
@@ -276,7 +276,7 @@ void KOPrefsDialog::setupLocaleTab()
syncPrefsGroup->groupBox()-> setOrientation (Qt::Vertical);
topLayout->addMultiCellWidget( syncPrefsGroup->groupBox(),iii,iii,0,1);
++iii;
- KPrefsWidBool *sb;
+ KPrefsDialogWidBool *sb;
if ( QApplication::desktop()->width() < 300 ) {
sb =
addWidBool(i18n("Week starts on Sunday"),
@@ -327,7 +327,7 @@ void KOPrefsDialog::setupSyncAlgTab()
topLayout->setMargin(marginHint());
int iii = 0;
- KPrefsWidBool *sb =
+ KPrefsDialogWidBool *sb =
addWidBool(i18n("Ask for preferences before syncing"),
&(KOPrefs::instance()->mAskForPreferences),topFrame);
topLayout->addMultiCellWidget(sb->checkBox(), iii,iii,0,1);
@@ -394,7 +394,7 @@ void KOPrefsDialog::setupSyncTab()
topLayout->addWidget(mLocalTempFile,iii,1);
++iii;
- KPrefsWidBool *wb =
+ KPrefsDialogWidBool *wb =
addWidBool(i18n("Write back synced file"),
&(KOPrefs::instance()->mWriteBackFile),topFrame);
topLayout->addMultiCellWidget(wb->checkBox(), iii,iii,0,1);
@@ -417,7 +417,7 @@ void KOPrefsDialog::setupMainTab()
topLayout->setSpacing(spacingHint());
topLayout->setMargin(marginHint());
- // KPrefsWidBool *emailControlCenter =
+ // KPrefsDialogWidBool *emailControlCenter =
// addWidBool(i18n("&Use email settings from Control Center"),
// &(KOPrefs::instance()->mEmailControlCenter),topFrame);
// topLayout->addMultiCellWidget(emailControlCenter->checkBox(),0,0,0,1);
@@ -433,7 +433,7 @@ void KOPrefsDialog::setupMainTab()
mEmailLabel = new QLabel(mEmailEdit, i18n("E&mail address:"),topFrame);
topLayout->addWidget(mEmailLabel,1,0);
topLayout->addWidget(mEmailEdit,1,1);
- KPrefsWidBool *wb;
+ KPrefsDialogWidBool *wb;
QHBox *dummy;
if ( QApplication::desktop()->width() > 480 ) {
dummy = new QHBox(topFrame);
@@ -476,7 +476,7 @@ void KOPrefsDialog::setupMainTab()
if ( QApplication::desktop()->width() < 300 )
mPrioSpin->setFixedWidth( 40 );
- // KPrefsWidBool *bcc =
+ // KPrefsDialogWidBool *bcc =
// addWidBool(i18n("Send copy to owner when mailing events"),
// &(KOPrefs::instance()->mBcc),topFrame);
// topLayout->addMultiCellWidget(bcc->checkBox(),4,4,0,1);
@@ -503,20 +503,20 @@ void KOPrefsDialog::setupMainTab()
mHourSizeSlider = new QSlider(24,47,1,24,Horizontal,agendasize);
topLayout->addMultiCellWidget(agendasize,7,7,0,1);
*/
- KPrefsWidBool *verticalScreen =
+ KPrefsDialogWidBool *verticalScreen =
addWidBool(i18n("Show vertical screen (Needs restart)"),
&(KOPrefs::instance()->mVerticalScreen),topFrame);
//topLayout->addWidget(verticalScreen->checkBox(),ii++,0);
topLayout->addMultiCellWidget(verticalScreen->checkBox(),7,7,0,1);
- KPrefsWidBool *ask =
+ KPrefsDialogWidBool *ask =
addWidBool(i18n("Ask for quit when closing KO/Pi"),
&(KOPrefs::instance()->mAskForQuit),topFrame);
topLayout->addMultiCellWidget(ask->checkBox(),8,8,0,1);
/*
- KPrefsWidBool *confirmCheck =
+ KPrefsDialogWidBool *confirmCheck =
addWidBool(i18n("Confirm &deletes"),&(KOPrefs::instance()->mConfirm),
topFrame);
topLayout->addMultiCellWidget(confirmCheck->checkBox(),7,7,0,1);
@@ -560,7 +560,7 @@ void KOPrefsDialog::setupMainTab()
mailClientGroup->addRadio(i18n("Sendmail"));
topLayout->addMultiCellWidget(mailClientGroup->groupBox(),11,11,0,1);
- KPrefsWidBool *htmlsave =
+ KPrefsDialogWidBool *htmlsave =
addWidBool(i18n("Export to HTML with every save"),&(KOPrefs::instance()->mHtmlWithSave),
topFrame);
topLayout->addMultiCellWidget(htmlsave->checkBox(),12,12,0,1);
@@ -640,7 +640,7 @@ void KOPrefsDialog::setupTimeTab()
addWidBool(i18n("Exclude Saturdays"),
&(KOPrefs::instance()->mExcludeSaturdays),excludeBox);
// KPrefsWidBool *marcusBainsShowSeconds = addWidBool(i18n("Show seconds on Marcus Bains line"),
// &(KOPrefs::instance()->mMarcusBainsShowSeconds),
// topFrame);
// topLayout->addWidget(marcusBainsShowSeconds->checkBox(),5,0);
@@ -678,7 +678,7 @@ void KOPrefsDialog::setupViewsTab()
int ii = 0;
- KPrefsWidBool *dummy =
+ KPrefsDialogWidBool *dummy =
addWidBool(i18n("Edit item on doubleclick (if not, show)"),
&(KOPrefs::instance()->mEditOnDoubleClick),topFrame);
topLayout->addWidget(dummy->checkBox(),ii++,0);
@@ -693,24 +693,24 @@ void KOPrefsDialog::setupViewsTab()
&(KOPrefs::instance()->mUseHighlightLightColor),topFrame);
topLayout->addWidget(dummy->checkBox(),ii++,0);
- KPrefsWidBool *dailyRecur =
+ KPrefsDialogWidBool *dailyRecur =
addWidBool(i18n("Show events that recur daily in date nav."),
&(KOPrefs::instance()->mDailyRecur),topFrame);
topLayout->addWidget(dailyRecur->checkBox(),ii++,0);
- KPrefsWidBool *weeklyRecur =
+ KPrefsDialogWidBool *weeklyRecur =
addWidBool(i18n("Show ev. that recur weekly in date nav."),
&(KOPrefs::instance()->mWeeklyRecur),topFrame);
topLayout->addWidget(weeklyRecur->checkBox(),ii++,0);
if ( QApplication::desktop()->width() > 640 ) {
- KPrefsWidBool *enableToolTips =
+ KPrefsDialogWidBool *enableToolTips =
addWidBool(i18n("Enable tooltips displaying summary of ev."),
&(KOPrefs::instance()->mEnableToolTips),topFrame);
topLayout->addWidget(enableToolTips->checkBox(),ii++,0);
}
- KPrefsWidBool *passwdk =
+ KPrefsDialogWidBool *passwdk =
addWidBool(i18n("Show parent To-Do's in What's Next view"),
&(KOPrefs::instance()->mWNViewShowsParents),topFrame);
topLayout->addWidget(passwdk->checkBox(), ii++,0);
@@ -726,7 +726,7 @@ void KOPrefsDialog::setupViewsTab()
topLayout->addWidget(passwdk->checkBox(), ii++,0);
- KPrefsWidBool *marcusBainsEnabled =
+ KPrefsDialogWidBool *marcusBainsEnabled =
addWidBool(i18n("Show Marcus Bains line"),
&(KOPrefs::instance()->mMarcusBainsEnabled),topFrame);
topLayout->addWidget(marcusBainsEnabled->checkBox(),ii++,0);
@@ -761,12 +761,12 @@ void KOPrefsDialog::setupViewsTab()
topLayout->addWidget(dummy->checkBox(),ii++,0);
- KPrefsWidBool *fullViewTodo =
+ KPrefsDialogWidBool *fullViewTodo =
addWidBool(i18n("Event list view uses full window"),
&(KOPrefs::instance()->mFullViewTodo),topFrame);
topLayout->addWidget(fullViewTodo->checkBox(),ii++,0);
- KPrefsWidBool *fullViewMonth =
+ KPrefsDialogWidBool *fullViewMonth =
addWidBool(i18n("Next days view uses full window"),
&(KOPrefs::instance()->mFullViewMonth),topFrame);
topLayout->addWidget(fullViewMonth->checkBox(),ii++,0);
@@ -843,7 +843,7 @@ void KOPrefsDialog::setupViewsTab()
topLayout->addMultiCellWidget(habo,ii, ii,0,1);
ii++;
#ifdef DESKTOP_VERSION
- KPrefsWidBool *enableMonthScroll =
+ KPrefsDialogWidBool *enableMonthScroll =
addWidBool(i18n("Enable scrollbars in month view cells"),
&(KOPrefs::instance()->mEnableMonthScroll),topFrame);
topLayout->addWidget(enableMonthScroll->checkBox(),ii++,0);
@@ -854,7 +854,7 @@ void KOPrefsDialog::setupViewsTab()
&(KOPrefs::instance()->mMonthViewSatSunTog),topFrame);
topLayout->addWidget(dummy->checkBox(),ii++,0);
- KPrefsWidBool *coloredCategoriesInMonthView =
+ KPrefsDialogWidBool *coloredCategoriesInMonthView =
addWidBool(i18n("Month view uses category colors"),
&(KOPrefs::instance()->mMonthViewUsesCategoryColor),topFrame);
topLayout->addWidget(coloredCategoriesInMonthView->checkBox(),ii++,0);
@@ -897,7 +897,7 @@ void KOPrefsDialog::setupViewsTab()
topLayout->setMargin(marginHint());
ii = 0;
- KPrefsWidBool *showCompletedTodo =
+ KPrefsDialogWidBool *showCompletedTodo =
addWidBool(i18n("To-do view shows completed Todos"),
&(KOPrefs::instance()->mShowCompletedTodo),topFrame);
topLayout->addWidget(showCompletedTodo->checkBox(),ii++,0);
@@ -1047,9 +1047,9 @@ void KOPrefsDialog::setupFontsTab()
QGridLayout *topLayout = new QGridLayout(topFrame,7,3);
topLayout->setSpacing(1);
topLayout->setMargin(3);
- KPrefsWidFont * tVFont;
+ KPrefsDialogWidFont * tVFont;
int i = 0;
- KPrefsWidFont *timeLabelsFont =
+ KPrefsDialogWidFont *timeLabelsFont =
addWidFont(i18n("23"),i18n("DateNavigator:(nr)"),
&(KOPrefs::instance()->mDateNavigatorFont),topFrame);
topLayout->addWidget(timeLabelsFont->label(),i,0);
@@ -1066,7 +1066,7 @@ void KOPrefsDialog::setupFontsTab()
topLayout->addWidget(timeLabelsFont->button(),i,2);
++i;
- KPrefsWidFont *timeBarFont =
+ KPrefsDialogWidFont *timeBarFont =
addWidFont(KGlobal::locale()->formatTime(QTime(12,34)),i18n("Time bar:"),
&(KOPrefs::instance()->mTimeBarFont),topFrame);
topLayout->addWidget(timeBarFont->label(),i,0);
@@ -1075,7 +1075,7 @@ void KOPrefsDialog::setupFontsTab()
++i;
- KPrefsWidFont *marcusBainsFont =
+ KPrefsDialogWidFont *marcusBainsFont =
addWidFont(KGlobal::locale()->formatTime(QTime(12,34,23)),i18n("M. Bains line:"),
&(KOPrefs::instance()->mMarcusBainsFont),topFrame);
topLayout->addWidget(marcusBainsFont->label(),i,0);
@@ -1122,7 +1122,7 @@ void KOPrefsDialog::setupFontsTab()
topLayout->addWidget(tVFont->preview(),i,1);
topLayout->addWidget(tVFont->button(),i,2);
++i;
- KPrefsWidFont *agendaViewFont =
+ KPrefsDialogWidFont *agendaViewFont =
addWidFont(i18n("Event text"),i18n("Agenda view:"),
&(KOPrefs::instance()->mAgendaViewFont),topFrame);
topLayout->addWidget(agendaViewFont->label(),i,0);
@@ -1131,7 +1131,7 @@ void KOPrefsDialog::setupFontsTab()
++i;
- KPrefsWidFont *monthViewFont =
+ KPrefsDialogWidFont *monthViewFont =
addWidFont(KGlobal::locale()->formatTime(QTime(12,34)) + " " + i18n("Event"),
i18n("Month view:"),&(KOPrefs::instance()->mMonthViewFont),topFrame);
topLayout->addWidget(monthViewFont->label(),i,0);
@@ -1140,7 +1140,7 @@ void KOPrefsDialog::setupFontsTab()
++i;
- KPrefsWidFont *lVFont =
+ KPrefsDialogWidFont *lVFont =
addWidFont(i18n("Event"),i18n("List View:"),
&(KOPrefs::instance()->mListViewFont),topFrame);
topLayout->addWidget(lVFont->label(),i,0);
@@ -1241,7 +1241,7 @@ void KOPrefsDialog::setupColorsTab()
topLayout->addWidget(workingHoursColor->label(),ii,0);
topLayout->addWidget(workingHoursColor->button(),ii++,1);
- KPrefsWidBool *sb =
+ KPrefsDialogWidBool *sb =
addWidBool(i18n("Use colors for application:"),
&(KOPrefs::instance()->mUseAppColors),topFrame);
topLayout->addMultiCellWidget(sb->checkBox(), ii, ii, 0,1 );
@@ -1675,7 +1675,7 @@ void KOPrefsDialog::setupTimeZoneTab()
}
mTimeZoneCombo->setCurrentItem(nCurrentlySet);
int iii = 1;
- KPrefsWidBool *sb =
+ KPrefsDialogWidBool *sb =
addWidBool(i18n("Timezone has daylight saving"),
&(KOPrefs::instance()->mUseDaylightsaving),topFrame);
topLayout->addMultiCellWidget(sb->checkBox(), iii,iii,0,1);
@@ -640,7 +640,7 @@ void KOPrefsDialog::setupTimeTab()
addWidBool(i18n("Exclude Saturdays"),
&(KOPrefs::instance()->mExcludeSaturdays),excludeBox);
-// KPrefsWidBool *marcusBainsShowSeconds = addWidBool(i18n("Show seconds on Marcus Bains line"),
+// KPrefsDialogWidBool *marcusBainsShowSeconds = addWidBool(i18n("Show seconds on Marcus Bains line"),
// &(KOPrefs::instance()->mMarcusBainsShowSeconds),
// topFrame);